==> eiffelstudio-18.01.10.1424.tar: F_code/C33/ql1613.c <==
/*
 * Code for class QL_METRIC_CLASS_BASIC_SCOPE_INFO
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ql1613.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {QL_METRIC_CLASS_BASIC_SCOPE_INFO}.make */
void F2170_24594 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	EIF_REFERENCE tr5 = NULL;
	RTCFDT;
	RTLD;
	
	RTLI(7);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,tr3);
	RTLR(4,tr4);
	RTLR(5,tr5);
	RTLR(6,arg1);
	RTLIU(7);
	
	RTEAA("make", 2169, Current, 0, 1, 24734);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNSMART(eif_final_id(Y21715,Y21715_gen_type,dftype,2161).id);
	F1_29(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	tr1 = F4502_52341(RTCW(tr1));
	{
		EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,3831,0,0xFFFF};
		EIF_TYPE typres0;
		typarr0[3] = dftype;
		
		typres0 = eif_compound_id(dftype, typarr0);
		tr2 = RTLNTS(typres0.id, 2, 0);
	}
	((EIF_TYPED_VALUE *)tr2+1)->it_r = Current;
	RTAR(tr2,Current);
	
	{
		static EIF_TYPE_INDEX typarr0[] = {3989,0xFFF9,1,3831,5098,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr5 = RTLNRF(typres0.id, (EIF_POINTER) __A1613_51_2, (EIF_POINTER) _A1613_51_2, (EIF_POINTER)(F2170_24598),tr2, 1, 1);
	}
	F2661_26754(RTCW(tr1), tr5);
	RTHOOK(3);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {QL_METRIC_CLASS_BASIC_SCOPE_INFO}.calculate_function */
EIF_REFERENCE F2170_24596 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {QL_METRIC_CLASS_BASIC_SCOPE_INFO}.domain_generator */
EIF_REFERENCE F2170_24597 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {QL_METRIC_CLASS_BASIC_SCOPE_INFO}.evaluate_item */
void F2170_24598 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REAL_64 tr8_1;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,arg1);
	RTLIU(4);
	
	RTEAA("evaluate_item", 2169, Current, 0, 1, 24738);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_1_) != NULL)) {
		RTHOOK(2);
		tr1 = *(EIF_REFERENCE *)(Current);
		tr2 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr8_1 = (FUNCTION_CAST(EIF_REAL_64, (EIF_POINTER, EIF_REFERENCE, EIF_REFERENCE)) *(EIF_POINTER *)(RTCW(tr2)+ _PTROFF_4_2_0_3_0_0_))(
			*(EIF_POINTER *)(RTCW(tr2)+ _PTROFF_4_2_0_3_0_1_),
			*(EIF_REFERENCE *)(RTCW(tr2) + _REFACS_1_), arg1);
		;
		tr8_1 = tr8_1;
		F2204_24830(RTCW(tr1), tr8_1);
	} else {
		RTHOOK(3);
		tr1 = *(EIF_REFERENCE *)(Current);
		F2204_24830(RTCW(tr1), (EIF_REAL_64) 1.0);
	}
	RTHOOK(4);
	RTLE;
	RTEE;
}

void EIF_Minit1613 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.07.10.1981.tar: F_code/C33/ql1613.c <==
/*
 * Code for class QL_METRIC_ASSERTION_BASIC_SCOPE_INFO
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ql1613.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {QL_METRIC_ASSERTION_BASIC_SCOPE_INFO}.make */
void F2169_24730 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	EIF_REFERENCE tr5 = NULL;
	RTCFDT;
	RTLD;
	
	RTLI(7);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,tr3);
	RTLR(4,tr4);
	RTLR(5,tr5);
	RTLR(6,arg1);
	RTLIU(7);
	
	RTEAA("make", 2168, Current, 0, 1, 24855);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNSMART(eif_final_id(Y21779,Y21779_gen_type,dftype,2166).id);
	F1_29(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	tr1 = F4508_52561(RTCW(tr1));
	{
		EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,3840,0,0xFFFF};
		EIF_TYPE typres0;
		typarr0[3] = dftype;
		
		typres0 = eif_compound_id(dftype, typarr0);
		tr2 = RTLNTS(typres0.id, 2, 0);
	}
	((EIF_TYPED_VALUE *)tr2+1)->it_r = Current;
	RTAR(tr2,Current);
	
	{
		static EIF_TYPE_INDEX typarr0[] = {3998,0xFFF9,1,3840,4847,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr5 = RTLNRF(typres0.id, (EIF_POINTER) __A1613_51_2, (EIF_POINTER) _A1613_51_2, (EIF_POINTER)(F2169_24734),tr2, 1, 1);
	}
	F2669_26960(RTCW(tr1), tr5);
	RTHOOK(3);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {QL_METRIC_ASSERTION_BASIC_SCOPE_INFO}.calculate_function */
EIF_REFERENCE F2169_24732 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {QL_METRIC_ASSERTION_BASIC_SCOPE_INFO}.domain_generator */
EIF_REFERENCE F2169_24733 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {QL_METRIC_ASSERTION_BASIC_SCOPE_INFO}.evaluate_item */
void F2169_24734 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REAL_64 tr8_1;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,arg1);
	RTLIU(4);
	
	RTEAA("evaluate_item", 2168, Current, 0, 1, 24859);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_1_) != NULL)) {
		RTHOOK(2);
		tr1 = *(EIF_REFERENCE *)(Current);
		tr2 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr8_1 = (FUNCTION_CAST(EIF_REAL_64, (EIF_POINTER, EIF_REFERENCE, EIF_REFERENCE)) *(EIF_POINTER *)(RTCW(tr2)+ _PTROFF_4_2_0_3_0_0_))(
			*(EIF_POINTER *)(RTCW(tr2)+ _PTROFF_4_2_0_3_0_1_),
			*(EIF_REFERENCE *)(RTCW(tr2) + _REFACS_1_), arg1);
		;
		tr8_1 = tr8_1;
		F2211_25033(RTCW(tr1), tr8_1);
	} else {
		RTHOOK(3);
		tr1 = *(EIF_REFERENCE *)(Current);
		F2211_25033(RTCW(tr1), (EIF_REAL_64) 1.0);
	}
	RTHOOK(4);
	RTLE;
	RTEE;
}

void EIF_Minit1613 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
